# [Zope-tests] FAILED : winbot / z3c.coverage_py_265_32

buildbot at winbot.zope.org buildbot at winbot.zope.org
Wed Feb 2 23:47:31 EST 2011

- Previous message: [Zope-tests] OK : Zope Buildbot / zopetoolkit-1.0-py2.5 slave-ubuntu64
- Next message: [Zope-tests] OK : Zope Buildbot / zopetoolkit-1.0-py2.6 slave-ubuntu64
- Messages sorted by: [ date ] [ thread ] [ subject ] [ author ]

    FAILED : winbot / z3c.coverage_py_265_32
    Build: http://winbot.zope.org/builders/z3c.coverage_py_265_32/builds/24

    Build Reason: The Nightly scheduler named 'z3c.coverage nightly' triggered this build

    Build Source Stamp: [branch z3c.coverage/trunk] HEAD

    Blamelist:

    Buildbot: http://winbot.zope.org/

- Previous message: [Zope-tests] OK : Zope Buildbot / zopetoolkit-1.0-py2.5 slave-ubuntu64
- Next message: [Zope-tests] OK : Zope Buildbot / zopetoolkit-1.0-py2.6 slave-ubuntu64
- Messages sorted by: [ date ] [ thread ] [ subject ] [ author ]

More information about the Zope-tests mailing list